@@ -34,8 +34,8 @@ import logging
 log = logging.getLogger("fsa")
 
 # module version…
-VERSION = "4.3.0dev"
-VERSION_NUM = (4, 3, -1)
+VERSION = "4.3.1"
+VERSION_NUM = (4, 3, 1)
 
 
 class AuthException(BaseException):
@@ -308,7 +308,8 @@ _DIRECTIVES = {
     "FSA_TOKEN_CARRIER", "FSA_TOKEN_DELAY", "FSA_TOKEN_GRACE",
     "FSA_TOKEN_LENGTH", "FSA_TOKEN_NAME", "FSA_REALM",
     "FSA_TOKEN_SECRET", "FSA_TOKEN_SIGN", "FSA_TOKEN_TYPE",
-    "FSA_URL_NAME", "FSA_USER_IN_GROUP", "FSA_LOGGING_LEVEL",
+    "FSA_TOKEN_RENEWAL", "FSA_URL_NAME", "FSA_USER_IN_GROUP",
+    "FSA_LOGGING_LEVEL",
 }
 
 
@@ -386,8 +387,8 @@ class FlaskSimpleAuth:
             if self._user and self._can_create_token():
                 if self._name in request.cookies:
                     user, exp = self._get_any_token_auth_exp(request.cookies[self._name])
-                    # reset token when only 25% time remains
-                    limit = dt.datetime.utcnow() + 0.25 * dt.timedelta(minutes=self._delay)
+                    # renew token when closing expiration
+                    limit = dt.datetime.utcnow() + self._renewal * dt.timedelta(minutes=self._delay)
                     set_cookie = exp < limit
                 else:
                     set_cookie = True
@@ -421,12 +422,13 @@ class FlaskSimpleAuth:
             self._auth, self._saved_auth = self._saved_auth, None
         return res
 
+    # NOTE for multiprocess setups:
+    # clearing a cache in a process does not tell others to do it as well…
     def _cache_function(self, fun):
         """Generate or regenerate cache for function."""
         # get the actual function when regenerating caches
         while hasattr(fun, "__wrapped__"):
             fun = fun.__wrapped__
-        # NOTE probaly maxsize should disable with None and unbound with 0.
         return fun if not fun or self._maxsize == 0 else \
             functools.lru_cache(maxsize=self._maxsize)(fun)
 
@@ -540,6 +542,7 @@ class FlaskSimpleAuth:
         # token expiration
         self._delay = conf.get("FSA_TOKEN_DELAY", 60.0)
         self._grace = conf.get("FSA_TOKEN_GRACE", 0.0)
+        self._renewal = conf.get("FSA_TOKEN_RENEWAL", 0.25)  # only for cookies
         # token signature
         if "FSA_TOKEN_SECRET" in conf:
             self._secret = conf["FSA_TOKEN_SECRET"]
